@@ -1,15 +1,17 @@
 import argparse
 import os
 
+from src.model.directory_path import DirectoryPath
+from src.model.file_path import FilePath
 from src.service.image_path_service import ImagePathService
 from src.service.markdown_file_service import MarkdownFileService
 from src.service.markdown_text_service import MarkdownTextService
 from src.service.s3_service import S3Service
-from src.model.file_path import FilePath
-from src.model.directory_path import DirectoryPath
 
 
 def main():
+    """ markdown-hiko
+    """
     parser = argparse.ArgumentParser()
     parser.add_argument("--file", "-f", help="path to Markdown file", required=True)
     parser.add_argument("--url", "-u", help="S2 or CloudFront domain name", required=True)
@@ -37,7 +39,7 @@ def main():
         image_path_service = ImagePathService(
             image_path=file,
             project_root_path=project_root_absolute_path,
-            markdown_file_directory_path=markdown_file_directory_path
+            markdown_file_directory_path=markdown_file_directory_path,
         )
         s3_service.upload_file(image_path_service.get_absolute_path())
 
@@ -46,5 +48,5 @@ def main():
     markdown_file_service.save_markdown(replaced_string)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
